#
# spec file for package opencensus-proto
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         census-instrumentation
%global repo            opencensus-proto
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

%define src_install_dir /usr/src/%{name}

Name:           opencensus-proto
Version:        0.3.0+git.20200721
Release:        bp156.2.1
Summary:        Protocol buffers for OpenCensus
License:        Apache-2.0
Group:          Development/Languages/Golang
URL:            https://%{provider_prefix}
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  golang-packaging
%{go_provides}

%description
Protocol buffers for OpenCensus - a framework for collecting metrics and
distributed traces from services.

%package source
Summary:        Source code of opencensus-proto
Group:          Development/Sources
BuildArch:      noarch

%description source
Protocol buffers for OpenCensus - a framework for collecting metrics and
distributed traces from services.

This package contains source code for googleapis.

%prep
%setup -q

%build
# TODO: Install go module from gen-go/ directory. It's not trivial, this
# project does not contain the vendor/ dir.

%install
# Install sources
mkdir -p %{buildroot}%{src_install_dir}
tar -xJf %{SOURCE0} --strip-components=1 -C %{buildroot}%{src_install_dir}

%files source
%license LICENSE
%doc README.md
%{src_install_dir}

%changelog
* Sun Aug 28 2022 jengelh@inai.de
- Update to version 0.3.0+git.20200721:
  * Bump version to 0.3.0
  * Generate Go types using  protocolbuffers/protobuf-go (#218)
  * Load proto_library() rule. (#216)
* Thu Dec 19 2019 svasudevan@suse.com
- Update to version 0.2.1+git.20190826:
  * Remove grpc_java dependency and java_proto rules. (#214)
  * Add C++ targets, especially for gRPC services. (#212)
  * Upgrade bazel and dependencies to latest. (#211)
  * Bring back bazel cache to make CI faster. (#210)
  * Travis: don't require sudo for bazel installation. (#209)
* Wed Sep 25 2019 mrostecki@opensuse.org
- Update to version 0.2.1:
  * Add grpc-gateway for metrics service. (#205)
  * Pin bazel version in travis builds (#207)
  * Update gen-go files (#199)
  * Add Web JS as a LibraryInfo.Language option (#198)
  * Set up Python packaging for PyPI release. (#197)
  * Add tracestate to links. (#191)
  * Python proto file generator and generated proto files (#196)
  * Ruby proto file generator and generated proto files (#192)
  * Add py_proto_library() rules for envoy/api. (#194)
  * Gradle: Upgrade dependency versions. (#193)
  * Update release versions for readme. (#189)
  * Start 0.3.0 development cycle
  * Update gen-go files. (#187)
  * Revert "Start 0.3.0 development cycle (#167)" (#183)
  * Revert optimization for metric descriptor and bucket options for now. (#184)
  * Constant sampler: add option to always follow the parent's decision. (#182)
  * Document that all maximum values must be specified. (#181)
  * Fix typo in bucket bounds. (#178)
  * Restrict people who can approve reviews. This is to ensure code quality. (#177)
  * Use bazel cache to make CI faster. (#176)
  * Add grpc generated files to the idea plugin. (#175)
  * Add Resource to Span (#174)
  * time is required (#170)
  * Upgrade protobuf dependency to v3.6.1.3. (#173)
  * assume Ok Status when not set (#171)
  * Minor comments fixes (#160)
  * Start 0.3.0 development cycle (#167)
  * Update gen-go files. (#162)
  * Update releasing instruction. (#163)
  * Fix Travis build. (#165)
  * Add OpenApi doc for trace agent grpc-gateway (#157)
  * Add command to generate OpenApi/Swagger doc for grpc-gateway (#156)
  * Update gen-go files (#155)
  * Add trace export grpc-gateway config (#77)
  * Fix bazel build after bazel upgrade (#154)
  * README: Add gitter, javadoc and godoc badge. (#151)
  * Update release versions for README. (#150)
  * Start 0.2.0 development cycle
  * Add resource and metrics_service proto to mkgogen. Re-generate gen-go files. (#147)
  * Add resource to protocol (#137)
  * Fix generating the javadoc. (#144)
  * Metrics/TimeSeries: start time should not be included while end time should. (#142)
  * README: Add instructions on using opencensus_proto with Bazel. (#140)
  * agent/README: update package info. (#138)
  * Agent: Add metrics service. (#136)
  * Tracing: Add default limits to TraceConfig. (#133)
  * Remove a stale TODO. (#134)
  * README: Add a note about go_proto_library rules. (#135)
  * add golang bazel build support (#132)
  * Remove exporter protos from mkgogen. (#128)
  * Update README and RELEASING. (#130)
  * Change histogram buckets definition to be OpenMetrics compatible. (#121)
  * Remove exporter/v1 protos. (#124)
  * Clean up the README for Agent proto. (#126)
  * Change Quantiles to ValuesAtPercentile. (#122)
  * Extend the TraceService service to support export/config for multiple Applications. (#119)
  * Add specifications on Agent implementation details. (#112)
  * Update gitignore (#118)
  * Remove maven support. Not used. (#116)
  * Add gauge distribution. (#117)
  * Add support for Summary type and value. (#110)
  * Add Maven status and instructions on adding dependencies. (#115)
  * Bump version to 0.0.3-SNAPSHOT
  * Bump version to 0.0.2
  * Update gen-go files. (#114)
  * Gradle: Add missing source and javadoc rules. (#113)
  * Add support for float attributes. (#98)
  * Change from mean to sum in distribution. (#109)
  * Bump version to v0.0.2-SNAPSHOT
  * Bump version to v0.0.1
  * Add releasing instructions in RELEASING.md. (#106)
  * Add Gradle build rules for generating gRPC service and releasing to Maven. (#102)
  * Re-organize proto directory structure. (#103)
  * Update gen-go files. (#101)
  * Add a note about interceptors of other libraries. (#94)
  * agent/common/v1: use exporter_version, core_library_version in LibraryInfo (#100)
  * opencensus/proto: add default Agent port to README (#97)
  * Update the message names for Config RPC. (#93)
  * Add details about agent protocol in the README. (#88)
  * Update gen-go files. (#92)
  * agent/trace/v1: fix signature for Config and comments too (#91)
  * Update gen-go files. (#86)
  * Make tracestate a list instead of a map to preserve ordering. (#84)
  * Allow MetricDescriptor to be sent only the first time. (#78)
  * Update mkgogen.sh. (#85)
  * Add agent trace service proto definitions. (#79)
  * Update proto and gen-go package names. (#83)
  * Add agent/common proto and BUILD. (#81)
  * Add trace_config.proto. (#80)
  * Build exporters with maven. (#76)
  * Make clear that cumulative int/float can go only up. (#75)
  * Add tracestate field to the Span proto. (#74)
  * gradle wrapper --gradle-version 4.9 (#72)
  * Change from multiple types of timeseries to have one. (#71)
  * Move exemplars in the Bucket. (#70)
  * Update gen-go files. (#69)
  * Move metrics in the top level directory. (#68)
  * Remove Range from Distribution. No backend supports this. (#67)
  * Remove unused MetricSet message. (#66)
  * Metrics: Add Exemplar to DistributionValue. (#62)
  * Gauge vs Cumulative. (#65)
  * Clarifying comment about bucket boundaries. (#64)
  * Make MetricDescriptor.Type capture the type of the value as well. (#63)
  * Regenerate the Go artifacts (#61)
  * Add export service proto (#60)
* Thu Jan 10 2019 Michał Rostecki <mrostecki@suse.de>
- Initial version 20180523
